@@ -7,7 +7,7 @@ import sys
 import tempfile
 from shutil import rmtree
 
-version = '21w11a'
+version = '21w16 dev'
 
 def file_type(file: str) -> str:
     if(not os.path.isfile(file)):
@@ -44,23 +44,28 @@ def comma_type(inp: str) -> list:
     ms = cleanList(ms, '\r\n\t')
     return ms
 
-def add_argument(*names, nargs=1, type=str, default=None, action='default',
-    range=None, choices=None, group=None, stack=None, help='', extra=''):
-    newDic = {}
-    newDic['names'] = names
-    newDic['nargs'] = nargs
-    newDic['type'] = type
-    newDic['default'] = default
-    newDic['action'] = action
-    newDic['help'] = help
-    newDic['extra'] = extra
-    newDic['range'] = range
-    newDic['choices'] = choices
-    newDic['grouping'] = group
-    newDic['stack'] = stack
-    return [newDic]
+def appendFileName(file_name, val):
+    dotIndex = file_name.rfind('.')
+    end = val + file_name[dotIndex:]
+    return file_name[:dotIndex] + end
+
+# Pad so that the av method works.
+def padChunk(item, totalFrames):
+    start = None
+    end = None
+    if(item[0] != 0):
+        start = [0, item[0], 2]
+    if(item[1] != totalFrames -1):
+        end = [item[1], totalFrames -1, 2]
+
+    if(start is None):
+        return [item] + [end]
+    if(end is None):
+        return [start] + [item]
+    return [start] + [item] + [end]
 
 def main_options():
+    from vanparse import add_argument
     ops = []
     ops += add_argument('urlOps', nargs=0, action='grouping')
     ops += add_argument('--format', type=str, group='urlOps',
@@ -132,6 +137,8 @@ def main_options():
         help='export as an XML file for Final Cut Pro instead of outputting a media file.')
     ops += add_argument('--export_as_json', action='store_true',
         help='export as a JSON file that can be read by auto-editor later.')
+    ops += add_argument('--export_as_clip_sequence', action='store_true',
+        help='export as multiple numbered media files.')
 
     ops += add_argument('--render', default='auto', choices=['av', 'opencv', 'auto'],
         help='choice which method to render video.')
@@ -221,38 +228,6 @@ def main_options():
         help='the path to a file, folder, or url you want edited.')
     return ops
 
-def create_options():
-    ops = []
-    ops += add_argument('--frame_rate', '-fps', '-r', type=float, default=30.0,
-        help='set the framerate for the output video.')
-    ops += add_argument('--duration', '-d', type=int, default=10,
-        help='set the length of the video (in seconds).')
-    ops += add_argument('--width', type=int, default=1280, #640
-        help='set the pixel width of the video.')
-    ops += add_argument('--height', type=int, default=720, #360
-        help='set the pixel height of the video.')
-    ops += add_argument('--output_file', '--output', '-o', type=str,
-        default='testsrc.mp4')
-    ops += add_argument('--my_ffmpeg', action='store_true',
-        help='use your ffmpeg and other binaries instead of the ones packaged.')
-    ops += add_argument('--help', '-h', action='store_true',
-        help='print info about the program or an option and exit.')
-    ops += add_argument('(input)', nargs='*',
-        help='the template')
-    return ops
-
-def info_options():
-    ops = []
-    ops += add_argument('--fast', action='store_true',
-        help='skip information that is very slow to get.')
-    ops += add_argument('--my_ffmpeg', action='store_true',
-        help='use your ffmpeg and other binaries instead of the ones packaged.')
-    ops += add_argument('--help', '-h', action='store_true',
-        help='print info about the program or an option and exit.')
-    ops += add_argument('(input)', nargs='*',
-        help='the path to a file you want inspected.')
-    return ops
-
 
 def main():
     dirPath = os.path.dirname(os.path.realpath(__file__))
@@ -278,14 +253,13 @@ def main():
     from vanparse import ParseOptions
     from usefulFunctions import Log, Timer
 
-    subcommands = ['create', 'test', 'info']
+    subcommands = ['create', 'test', 'info', 'levels']
 
     if(len(sys.argv) > 1 and sys.argv[1] in subcommands):
         if(sys.argv[1] == 'create'):
-            args = ParseOptions(sys.argv[2:], Log(), 'create', create_options())
-
-            from create import create
+            from create import create, create_options
             from usefulFunctions import FFmpeg
+            args = ParseOptions(sys.argv[2:], Log(), 'create', create_options())
 
             ffmpeg = FFmpeg(dirPath, args.my_ffmpeg, True, Log())
             create(ffmpeg, args.input, args.output_file, args.frame_rate, args.duration,
@@ -296,16 +270,25 @@ def main():
             testAutoEditor()
 
         if(sys.argv[1] == 'info'):
-            args = ParseOptions(sys.argv[2:], Log(), 'info', info_options())
-
-            from info import getInfo
+            from info import getInfo, info_options
             from usefulFunctions import FFmpeg, FFprobe
 
+            args = ParseOptions(sys.argv[2:], Log(), 'info', info_options())
+
             log = Log()
             ffmpeg = FFmpeg(dirPath, args.my_ffmpeg, False, log)
             ffprobe = FFprobe(dirPath, args.my_ffmpeg, False, log)
-
             getInfo(args.input, ffmpeg, ffprobe, args.fast, log)
+        if(sys.argv[1] == 'levels'):
+            from levels import levels, levels_options
+            from usefulFunctions import FFmpeg, FFprobe
+            args = ParseOptions(sys.argv[2:], Log(), 'levels', levels_options())
+
+            TEMP = tempfile.mkdtemp()
+            log = Log(temp=TEMP)
+            ffmpeg = FFmpeg(dirPath, args.my_ffmpeg, False, log)
+            ffprobe = FFprobe(dirPath, args.my_ffmpeg, False, log)
+            levels(args.input, args.track, args.output_file, ffmpeg, ffprobe, TEMP, log)
         sys.exit()
     else:
         option_data = main_options()
@@ -319,6 +302,10 @@ def main():
     ffmpeg = FFmpeg(dirPath, args.my_ffmpeg, args.show_ffmpeg_debug, Log())
     ffprobe = FFprobe(dirPath, args.my_ffmpeg, args.show_ffmpeg_debug, Log())
 
+    # Stops "The file {file} does not exist." from showing.
+    if(args.export_as_clip_sequence):
+        args.no_open = True
+
     makingDataFile = (args.export_to_premiere or args.export_to_resolve or
         args.export_to_final_cut_pro or args.export_as_json)
     is64bit = '64-bit' if sys.maxsize > 2**32 else '32-bit'
@@ -418,13 +405,14 @@ def main():
             log.debug('Reading .json file')
             from makeCutList import readCutList
             INPUT_FILE, chunks, speeds = readCutList(INPUT_FILE, version, log)
-
             newOutput = newOutputName(INPUT_FILE, args.export_as_audio,
                 args.export_to_final_cut_pro, makingDataFile, False)
 
             fileFormat = INPUT_FILE[INPUT_FILE.rfind('.'):]
         else:
             newOutput = args.output_file[i]
+            if(not os.path.isdir(INPUT_FILE) and '.' not in newOutput):
+                newOutput += INPUT_FILE[INPUT_FILE.rfind('.'):]
 
         log.debug(f'   - INPUT_FILE: {INPUT_FILE}')
         log.debug(f'   - newOutput: {newOutput}')
@@ -586,9 +574,7 @@ def main():
 
         if(fps is None and not audioFile):
             if(makingDataFile):
-                dotIndex = INPUT_FILE.rfind('.')
-                end = '_constantFPS' + INPUT_FILE[dotIndex:]
-                constantLoc = INPUT_FILE[:dotIndex] + end
+                constantLoc = appendFileName(INPUT_FILE, '_constantFPS')
             else:
                 constantLoc = f'{TEMP}{sep()}constantVid{fileFormat}'
             ffmpeg.run(['-i', INPUT_FILE, '-filter:v', 'fps=fps=30', constantLoc])
@@ -617,54 +603,77 @@ def main():
                 sampleRate, audioFile, fps, log)
             continue
 
-        if(audioFile):
+        def makeAudioFile(input_, chunks, output):
             from fastAudio import fastAudio, handleAudio, convertAudio
-            theFile = handleAudio(ffmpeg, INPUT_FILE, audioBitrate, str(sampleRate),
+            theFile = handleAudio(ffmpeg, input_, audioBitrate, str(sampleRate),
                 TEMP, log)
             fastAudio(theFile, f'{TEMP}{sep()}convert.wav', chunks, speeds, log, fps,
                 args.machine_readable_progress, args.no_progress)
-            convertAudio(ffmpeg, ffprobe, f'{TEMP}{sep()}convert.wav', INPUT_FILE,
-                newOutput, args, log)
+            convertAudio(ffmpeg, ffprobe, f'{TEMP}{sep()}convert.wav', input_,
+                output, args, log)
+
+        if(audioFile):
+            if(args.export_as_clip_sequence):
+                i = 1
+                for item in chunks:
+                    if(speeds[item[2]] == 99999):
+                        continue
+                    makeAudioFile(INPUT_FILE, [item], appendFileName(newOutput, f'-{i}'))
+                    i += 1
+            else:
+                makeAudioFile(INPUT_FILE, chunks, newOutput)
             continue
 
-        from videoUtils import handleAudioTracks, muxVideo
-
-        continueVid = handleAudioTracks(ffmpeg, newOutput, args, tracks, chunks, speeds,
-            fps, TEMP, log)
-        if(continueVid):
-            if(args.render == 'auto'):
-                if(args.zoom != [] or args.rectangle != []):
-                    args.render = 'opencv'
-                else:
-                    try:
-                        import av
-                        args.render = 'av'
-                    except ImportError:
+        def makeVideoFile(input_, chunks, output):
+            from videoUtils import handleAudioTracks, muxVideo
+            continueVid = handleAudioTracks(ffmpeg, output, args, tracks, chunks, speeds,
+                fps, TEMP, log)
+            if(continueVid):
+                if(args.render == 'auto'):
+                    if(args.zoom != [] or args.rectangle != []):
                         args.render = 'opencv'
+                    else:
+                        try:
+                            import av
+                            args.render = 'av'
+                        except ImportError:
+                            args.render = 'opencv'
 
-            log.debug(f'Using {args.render} method')
-            if(args.render == 'av'):
+                log.debug(f'Using {args.render} method')
+                if(args.render == 'av'):
+                    if(args.zoom != []):
+                        log.error('Zoom effect is not supported on the av render method.')
 
-                if(args.zoom != []):
-                    log.error('Zoom effect is not supported on the av render method.')
+                    if(args.rectangle != []):
+                        log.error('Rectangle effect is not supported on the av render method.')
 
-                if(args.rectangle != []):
-                    log.error('Rectangle effect is not supported on the av render method.')
+                    from renderVideo import renderAv
+                    renderAv(ffmpeg, ffprobe, input_, args, chunks, speeds, fps,
+                    TEMP, log)
 
-                from renderVideo import renderAv
-                renderAv(ffmpeg, ffprobe, INPUT_FILE, args, chunks, speeds, fps,
-                TEMP, log)
+                if(args.render == 'opencv'):
+                    from renderVideo import renderOpencv
+                    renderOpencv(ffmpeg, ffprobe, input_, args, chunks, speeds, fps,
+                        effects, TEMP, log)
 
-            if(args.render == 'opencv'):
-                from renderVideo import renderOpencv
-                renderOpencv(ffmpeg, ffprobe, INPUT_FILE, args, chunks, speeds, fps,
-                    effects, TEMP, log)
+                # Now mix new audio(s) and the new video.
+                muxVideo(ffmpeg, output, args, tracks, TEMP, log)
+                if(output is not None and not os.path.isfile(output)):
+                    log.bug(f'The file {output} was not created.')
 
-            # Now mix new audio(s) and the new video.
-            muxVideo(ffmpeg, newOutput, args, tracks, TEMP, log)
+        if(args.export_as_clip_sequence):
+            i = 1
+            totalFrames = chunks[len(chunks) - 1][1]
+            speeds.append(99999) # guarantee we have a cut speed to work with.
+            for item in chunks:
+                if(speeds[item[2]] == 99999):
+                    continue
 
-    if(newOutput is not None and not os.path.isfile(newOutput)):
-        log.bug(f'The file {newOutput} was not created.')
+                makeVideoFile(INPUT_FILE, padChunk(item, totalFrames),
+                    appendFileName(newOutput, f'-{i}'))
+                i += 1
+        else:
+            makeVideoFile(INPUT_FILE, chunks, newOutput)
 
     if(not args.preview and not makingDataFile):
         timer.stop()
