@@ -1,10 +1,8 @@
 '''wavfile.py'''
+# View the original code here:
+#   https://github.com/scipy/scipy/blob/master/scipy/io/wavfile.py
 
 """
-This file was copied from SciPy and therefore has a different code.
-View code here: https://github.com/scipy/scipy/blob/master/scipy/io/wavfile.py
-
-
 Copyright Notice
 -----------------
 
